@@ -18,10 +18,12 @@ from vsource.algorithms.salient_object_detection import salient_object_detection
 from vsource.algorithms.landmark_detection import landmark_detection
 from vsource.algorithms.binary_segmentation import binary_segmentation
 from vsource.algorithms.face_attribute_x import face_attribute_x
+from vsource.algorithms.text_generation import text_generation
+from vsource.algorithms.github_avatar_generation import github_avatar_generation
 
 from vsource.scripts.algorithm_scripts.algorithms import parse_algorithm
 from vsource.scripts.enroll_service import enroll
 
-__version__ = 'v1.1.2'
+__version__ = 'v1.1.4'
 __author__  = 'Ecohnoch'
 __email__   = 'chuyuan@vsource.club'
\ No newline at end of file
